/*****************************************************************************
*
*   Analog Devices, Inc.
*   ADSP-BF537 EZ-Kit Lite
*   Networked Audio Client
*
******************************************************************************
*
*   File        :   audio.c
*
*   Description :   This file contains routines for the audio flow control
*                   thread.
*
******************************************************************************
*   Revision History
******************************************************************************
*   date        rev     by      description
*-----------------------------------------------------------------------------
*   02.27.07    01.02h  KCK     Original release.
*****************************************************************************/
#include <cdefBF537.h>
#include "audioflow.h"
#include "audio.h"


/*****************************************************************************
*   This routine adjusts the I2S output clock in order to prevent buffer 
*   overflow or underflow.  We only want to make the adjustment for a certain
*   number of mS in order to add some hysteresis and minimize the distortion.
*   The adjustment values are passed from AudioOutCallback().
*****************************************************************************/

void
audioflow_RunFunction(void **inPtr)
    {

    while (1)
        {
        // apply the timing updates so that we are only adjusting for a certain number of mS
        *pSPORT0_TCLKDIV = sportTCLKDIVAdjust;

        VDK_PendSemaphore(kAudioFlowTimer, (AUDIO_TCLKDIV_ADJ_PER | VDK_kNoTimeoutError));  // wait for XX mS


        }
    }

int
audioflow_ErrorFunction(void **inPtr)
    {

    VDK_CThread_Error(VDK_GetThreadID());
    return 0;
    }

void
audioflow_InitFunction(void **inPtr, VDK_ThreadCreationBlock *pTCB)
    {
    }

void
audioflow_DestroyFunction(void **inPtr)
    {
    }

