/*****************************************************************************
*
*   Analog Devices, Inc.
*   ADSP-BF537 EZ-Kit Lite
*   Networked Audio Server
*
******************************************************************************
*
*   File        :   audiosend.c
*
*   Description :   This file contains routines for sending audio packets
*                   over the network.
*
******************************************************************************
*   Revision History
******************************************************************************
*   date        rev     by      description
*-----------------------------------------------------------------------------
*   02.27.07    01.02h  KCK     Original release.
*****************************************************************************/
#include <cdefBF537.h>
#include <lwip/sockets.h>
#include <services/services.h>      // system service includes
#include <drivers/adi_dev.h>        // device manager includes


#include "system.h"
#include "audiosend.h"
#include "audio.h"
#include "queue.h"


int audioSendCount = 0;

void
audiosend_RunFunction(void **inPtr)
    {

    int i;
    int result;
    ADI_DEV_1D_BUFFER *ptr;
    void *critical;
    void *arg;


    while (1)
        {
        VDK_PendSemaphore(kaudioPacketAvailable, 0);

        critical = adi_int_EnterCriticalRegion(arg);
        ptr = QueuePop(&audioQueue);
        adi_int_ExitCriticalRegion(critical);

        // if a valid packet was pulled off the queue 
        // AND we haven't transmitted too many packets since the last keep alive from the client
        if ((ptr != NULL) && (audioPacketCount < AUDIO_PACKET_MAX))
            {
            ++audioPacketCount;
            result = send(audioSocketID, ptr->Data, AUDIO_BUFFER_LEN, 0);

//            ptr->pNext = (ADI_DEV_1D_BUFFER *)NULL;                         // We are done with the inbound buffer
//            adi_dev_Read(audioInHandle, ADI_DEV_1D, (ADI_DEV_BUFFER *)ptr); // Re-queue it back with SPORT driver

            ++audioSendCount;

            if (audioSendCount == AUDIO_BUFFER_COUNT)
                {
                audioSendCount = 0;
                *pPORTFIO_TOGGLE = 0x0800;  // toggle LED 6
                }
            }
        }
    }

int
audiosend_ErrorFunction(void **inPtr)
    {

    VDK_CThread_Error(VDK_GetThreadID());
    return 0;
    }

void
audiosend_InitFunction(void **inPtr, VDK_ThreadCreationBlock *pTCB)
    {
    }

void
audiosend_DestroyFunction(void **inPtr)
    {
    }
