/*****************************************************************************
*
*   Analog Devices, Inc.
*   ADSP-BF537 EZ-Kit Lite
*   Networked Audio Server
*
******************************************************************************
*
*   File        :   queue.c
*
*   Description :   This file contains routines to handle queueing functions.
*
******************************************************************************
*   Revision History
******************************************************************************
*   date        rev     by      description
*-----------------------------------------------------------------------------
*   02.27.07    01.02h  KCK     Original release.
*****************************************************************************/

#include <stdio.h>
#include "queue.h"




int
QueueInit(queue_t *queue, queueEntry_t *queueEntry, int len)
    {
    int i;

    queue->size = 0;
    queue->len = len;
    queue->head = queueEntry;
    queue->tail = queueEntry;

    for (i = 0; i < (len - 1); ++i)
        {
        queueEntry[i].next = &queueEntry[i + 1];
        }
    queueEntry[len - 1].next = &queueEntry[0];

    return(0);
    }

int 
QueuePush(queue_t *queue, void *newEntry)
    {
    int ret = -1;

    // adjust size and place new entry on the queue
    if (! (queue->size == queue->len) )
        {
        queue->size++;
        queue->tail->entry = newEntry;
        queue->tail = queue->tail->next;

        // check to see of queue is full
        if (queue->size != queue->len)
            {
            ret = 0;
            }
        }

    return(ret);
    }

void *QueuePop(queue_t *queue)
    {
    void *ret = NULL;

    // check to see if queue is not empty
    if (queue->size != 0)
        {
        // adjust size and return the oldest entry
        queue->size--;

        ret = queue->head->entry;
        queue->head = queue->head->next;
        }

    return(ret);
    }

